@@ -16,15 +16,14 @@
 #include "gui/widgets/setupwidget.h"
 #include "preferences.h"
 
+#include <KgThemeSelector>
+#include <KStandardGameAction>
+
 #include <QAction>
 #include <KActionCollection>
 #include <KConfigDialog>
-#include <KNS3/DownloadDialog>
-#include <KStandardGameAction>
 #include <KToggleAction>
 #include <QIcon>
-#define USE_UNSTABLE_LIBKDEGAMESPRIVATE_API
-#include <libkdegamesprivate/kgamethemeselector.h>
 
 #include <QDockWidget>
 #include <QFileDialog>
@@ -140,18 +139,6 @@ bool MainWindow::loadGame(const QString &fileName)
     }
 }
 
-void MainWindow::getMoreGames()
-{
-    KNS3::DownloadDialog dialog(QStringLiteral("kigo-games.knsrc"), this);
-    dialog.exec();
-
-    /*KNS3::Entry::List entries = dialog.changedEntries();
-    if (entries.size() > 0) {
-        // do something with the modified entries here if you want
-        // such as rescaning your data folder or whatnot
-    }*/
-}
-
 void MainWindow::backendError()
 {
     m_gameView->setInteractive(false);
@@ -309,7 +296,8 @@ void MainWindow::showPreferences()
 
     KConfigDialog *dialog = new KConfigDialog(this, QStringLiteral("settings"), Preferences::self());
     dialog->addPage(new GeneralConfig(), i18n("General"), QStringLiteral("preferences-other"));
-    dialog->addPage(new KGameThemeSelector(dialog, Preferences::self(), KGameThemeSelector::NewStuffDisableDownload), i18n("Themes"), QStringLiteral("games-config-theme"));
+    dialog->addPage(new KgThemeSelector(ThemeRenderer::self()->themeProvider(), KgThemeSelector::EnableNewStuffDownload),
+                    i18n("Themes"), QStringLiteral("games-config-theme"));
     if (QPushButton *restore = dialog->button(QDialogButtonBox::RestoreDefaults)) {
         restore->hide();
     }
@@ -322,8 +310,6 @@ void MainWindow::applyPreferences()
     //qCDebug(KIGO_LOG) << "Update settings based on changed configuration...";
     m_gameScene->showLabels(Preferences::showBoardLabels());
 
-    ThemeRenderer::self()->loadTheme(Preferences::theme());
-
     if (!isBackendWorking()) {
         backendError();
     } else if (m_game->engineCommand() != Preferences::engineCommand()) {
@@ -391,10 +377,9 @@ void MainWindow::setupActions()
     m_newGameAction = KStandardGameAction::gameNew(this, &MainWindow::newGame, actionCollection());
     m_loadGameAction = KStandardGameAction::load(
         this, qOverload<>(&MainWindow::loadGame), actionCollection());
-    m_getMoreGamesAction = new QAction(QIcon::fromTheme( QStringLiteral( "get-hot-new-stuff") ), i18nc("@action", "Get More Games..." ), this);
+    m_getMoreGamesAction = new KNSWidgets::Action(i18nc("@action", "Get More Games..." ), QStringLiteral("kigo-games.knsrc"), actionCollection());
     actionCollection()->setDefaultShortcut(m_getMoreGamesAction, Qt::CTRL | Qt::Key_G);
     m_getMoreGamesAction->setToolTip(i18nc("@action", "Get More Games..."));
-    connect(m_getMoreGamesAction, &QAction::triggered, this, &MainWindow::getMoreGames);
     actionCollection()->addAction( QStringLiteral( "get_more_games" ), m_getMoreGamesAction);
     m_saveAction = KStandardGameAction::save(this, &MainWindow::saveGame, actionCollection());
     KStandardGameAction::quit(this, &QWidget::close, actionCollection());
